import { EventHandler, PeerTubeResolution, PeerTubeTextTrack, PlayerEventType } from './definitions';
/**
 * Allows for programmatic control of a PeerTube embed running in an <iframe>
 * within a web page.
 */
export declare class PeerTubePlayer {
    private readonly embedElement;
    private readonly scope?;
    private readonly eventRegistrar;
    private channel;
    private readyPromise;
    /**
     * Construct a new PeerTubePlayer for the given PeerTube embed iframe.
     * Optionally provide a `scope` to ensure that messages are not crossed
     * between multiple PeerTube embeds. The string passed here must match the
     * `scope=` query parameter on the embed URL.
     *
     * @param embedElement
     * @param scope
     */
    constructor(embedElement: HTMLIFrameElement, scope?: string);
    /**
     * Destroy the player object and remove the associated player from the DOM.
     */
    destroy(): void;
    /**
     * Listen to an event emitted by this player.
     *
     * @param event One of the supported event types
     * @param handler A handler which will be passed an event object (or undefined if no event object is included)
     */
    addEventListener(event: PlayerEventType, handler: EventHandler<any>): boolean;
    /**
     * Remove an event listener previously added with addEventListener().
     *
     * @param event The name of the event previously listened to
     * @param handler
     */
    removeEventListener(event: PlayerEventType, handler: EventHandler<any>): boolean;
    /**
     * Promise resolves when the player is ready.
     */
    get ready(): Promise<void>;
    /**
     * Tell the embed to start/resume playback
     */
    play(): Promise<void>;
    /**
     * Tell the embed to pause playback.
     */
    pause(): Promise<void>;
    /**
     * Tell the embed to change the audio volume
     *
     * @param value A number from 0 to 1
     */
    setVolume(value: number): Promise<void>;
    /**
     * Get the current volume level in the embed.
     *
     * @param value A number from 0 to 1
     */
    getVolume(): Promise<number>;
    /**
     * Tell the embed to change the current caption
     *
     * @param value Caption id
     */
    setCaption(value: string): Promise<void>;
    /**
     * Get video captions
     */
    getCaptions(): Promise<PeerTubeTextTrack[]>;
    /**
     * Tell the embed to seek to a specific position (in seconds)
     *
     * @param seconds
     */
    seek(seconds: number): Promise<void>;
    /**
     * Tell the embed to switch resolutions to the resolution identified
     * by the given ID.
     *
     * @param resolutionId The ID of the resolution as found with getResolutions()
     */
    setResolution(resolutionId: any): Promise<void>;
    /**
     * Retrieve a list of the available resolutions. This may change later, listen to the
     * `resolutionUpdate` event with `addEventListener` in order to be updated as the available
     * resolutions change.
     */
    getResolutions(): Promise<PeerTubeResolution[]>;
    /**
     * Retrieve a list of available playback rates.
     */
    getPlaybackRates(): Promise<number[]>;
    /**
     * Get the current playback rate. Defaults to 1 (1x playback rate).
     */
    getPlaybackRate(): Promise<number>;
    /**
     * Set the playback rate. Should be one of the options returned by getPlaybackRates().
     * Passing 0.5 means half speed, 1 means normal, 2 means 2x speed, etc.
     *
     * @param rate
     */
    setPlaybackRate(rate: number): Promise<void>;
    /**
     * Play next video in playlist
     */
    playNextVideo(): Promise<void>;
    /**
     * Play previous video in playlist
     */
    playPreviousVideo(): Promise<void>;
    /**
     * Get video position currently played (starts from 1)
     */
    getCurrentPosition(): Promise<number>;
    private constructChannel;
    private prepareToBeReady;
    private sendMessage;
}
